Crate secretstore

Crate secretstore 

SecretStore is a generic solution for storing some small secret data in a password-protected encrypted file. A typical example is a wallet storing the secret seed. See also crate seedstore ([SeedStore] and [KeyStore])

Structs

Options
Various config options for usage, such as allow weak password.
SecretStore
Store a secret data in an encrypred file. Also store some nonsecret data. Can be loaded from an encrypted file. The secret is stored in memory scrambled (using an ephemeral scrambling key). Secret data length can be between 1 and 65535 bytes. See also SecretStoreCreator.
SecretStoreCreator
Helper class for creating the store from given data. Should be used only by the utility that creates the encrypted file. See also SecretStore.